/** @file gsConfig.h

    @brief Provides preprocessor directives configuration of G+Smo

    This file is part of the G+Smo library. 
    It is autogenerated from gsConfig.h.in during the cmake
    configuration of G+Smo. If you need to make changes edit the
    original file in the sources and NOT THIS FILE.

    This Source Code Form is subject to the terms of the Mozilla Public
    License, v. 2.0. If a copy of the MPL was not distributed with this
    file, You can obtain one at http://mozilla.org/MPL/2.0/.
    
    Author(s): A. Mantzaflaris
*/

#pragma once

/** Define the G+Smo version number. */
#define GISMO_VERSION    "21.12.0"
#define GISMO_MAJOR      21
#define GISMO_MINOR      12
#define GISMO_PATCH      0

/** Define default coefficient type. */
#define GISMO_COEFF_TYPE double
#ifndef real_t
#define real_t           GISMO_COEFF_TYPE
#endif

/** Define default index type. */
#define index_t          int

/** Define default dimension type. */
#define short_t          int //short

/** Define the file data directory. */
#define GISMO_DATA_DIR "/usr/share/gismodata/"

/** Define the search paths. */
#define GISMO_SEARCH_PATHS "/tmp/SBo/slackrepo.52eimP/build_gismo/gismo-21.12.0/filedata/"

/** Define the file configuration directory. */
#define GISMO_CONFIG_DIR "/tmp/SBo/slackrepo.52eimP/build_gismo/gismo-21.12.0/build/config/"

/* Enabled Extensions */
/* #undef GISMO_WITH_ADIFF */
/* #undef GISMO_WITH_CODIPACK */
/* #undef GISMO_WITH_IPOPT */
/* #undef GISMO_WITH_MPFR */
/* #undef GISMO_WITH_MPI */
/* #undef GISMO_WITH_GMP */
/* #undef GISMO_WITH_ONURBS */
/* #undef GISMO_WITH_OCC */
/* #undef GISMO_WITH_PARDISO */
/* #undef GISMO_WITH_PASTIX */
/* #undef GISMO_WITH_PSOLID */
/* #undef GISMO_WITH_SPECTRA */
/* #undef GISMO_WITH_SUPERLU */
/* #undef GISMO_WITH_TAUCS */
/* #undef GISMO_WITH_TRILINOS */
/* #undef GISMO_WITH_UMFPACK */
/* #undef GISMO_WITH_UNUM */

/* Only include new types here that can be set as real_t */

#ifdef GISMO_WITH_MPFR
#include <mpreal.h>
#endif

#ifdef GISMO_WITH_GMP
#include <gmpxx.h>
#include <unsupported/Eigen/MPQClassExtra>
#endif

#ifdef GISMO_WITH_UNUM
#include <gsUnum/gsUnum.h>
#endif

#ifdef GISMO_WITH_CODIPACK
#include <gsCoDiPack/gsCoDiPack.h>
#endif

/* Determine if only header files should be used. */
#define GISMO_BUILD_LIB
/* #undef GISMO_HAS_EXTERN_TEMPLATES */

/* Debug settings. */
/* #undef GISMO_EXTRA_DEBUG */
/* #undef GISMO_WARNINGS */

/**
 * @name Eigen options - MUST be defined before Eigen is included
 * @{
 */

/* 
   Eigen options -- these MUST be defined before Eigen is included.

   See: 
   http://eigen.tuxfamily.org/dox/TopicPreprocessorDirectives.html
*/

/*  Index type */
/** Eigen options -- these MUST be defined before Eigen is included.\n
   See: http://eigen.tuxfamily.org/dox/TopicPreprocessorDirectives.html
   
   Index type
*/
#define EIGEN_DEFAULT_DENSE_INDEX_TYPE  index_t

/** Eigen options -- these MUST be defined before Eigen is included.\n
   See: http://eigen.tuxfamily.org/dox/TopicPreprocessorDirectives.html
   
   Index type
*/
#define EIGEN_DEFAULT_SPARSE_INDEX_TYPE index_t

/** Eigen options -- these MUST be defined before Eigen is included.\n
   See: http://eigen.tuxfamily.org/dox/TopicPreprocessorDirectives.html
  
 Matrix storage order
*/
#define EIGEN_DEFAULT_TO_COL_MAJOR

/** Eigen options -- these MUST be defined before Eigen is included.\n
  See: http://eigen.tuxfamily.org/dox/TopicPreprocessorDirectives.html
  
  Compile-time static assertions are replaced by runtime assertions;
  this saves compilation time. */
#define EIGEN_NO_STATIC_ASSERT

/** Eigen options -- these MUST be defined before Eigen is included.\n
    See http://eigen.tuxfamily.org/dox/TopicUsingIntelMKL.html */
/* #undef EIGEN_USE_MKL_ALL */

/* #undef EIGEN_DONT_VECTORIZE */
/* #undef EIGEN_DISABLE_UNALIGNED_ARRAY_ASSERT */
/**@}*/
